@@ -334,79 +334,6 @@ macro_rules! impl_produce {
 
 impl_produce!(i64, f64, String,);
 
-macro_rules! impl_vec_produce {
-    ($($t: ty,)+) => {
-        $(
-            impl<'r, 'a> Produce<'r, Vec<$t>> for BigQuerySourceParser {
-                type Error = BigQuerySourceError;
-
-                #[throws(BigQuerySourceError)]
-                fn produce(&mut self) -> Vec<$t> {
-                    let (_, cidx) = self.next_loc()?;
-                    if cidx == 0 {
-                        self.iter.next_row();
-                    }
-                    let v = self.iter
-                                .get_json_value(cidx)?
-                                .ok_or_else(|| anyhow!("cannot get json value"))?;
-                    let s = v
-                        .as_str()
-                        .ok_or_else(|| anyhow!("cannot get str from json value"))?;
-
-                    match s {
-                        "{}" => vec![],
-                        _ if s.len() < 3 => throw!(ConnectorXError::cannot_produce::<$t>(Some(s.into()))),
-                        s => s[1..s.len() - 1]
-                            .split(",")
-                            .map(|v| {
-                                v.parse()
-                                    .map_err(|_| ConnectorXError::cannot_produce::<$t>(Some(s.into())))
-                            })
-                            .collect::<Result<Vec<$t>, ConnectorXError>>()?,
-                    }
-                }
-            }
-
-            impl<'r, 'a> Produce<'r, Option<Vec<$t>>> for BigQuerySourceParser {
-                type Error = BigQuerySourceError;
-
-                #[throws(BigQuerySourceError)]
-                fn produce(&mut self) -> Option<Vec<$t>> {
-                    let (_, cidx) = self.next_loc()?;
-                    if cidx == 0 {
-                        self.iter.next_row();
-                    }
-
-                    let jsvalue = self.iter.get_json_value(cidx)?;
-                    match jsvalue {
-                        None => None,
-                        Some(value) => {
-                            let s =value
-                                .as_str()
-                                .ok_or_else(|| anyhow!("cannot get str from json value"))?;
-                            match s {
-                                "{}" => Some(vec![]),
-                                _ if s.len() < 3 => throw!(ConnectorXError::cannot_produce::<$t>(Some(s.into()))),
-                                s => Some(
-                                    s[1..s.len() - 1]
-                                        .split(",")
-                                        .map(|v| {
-                                            v.parse()
-                                                .map_err(|_| ConnectorXError::cannot_produce::<$t>(Some(s.into())))
-                                        })
-                                        .collect::<Result<Vec<$t>, ConnectorXError>>()?,
-                                ),
-                            }
-                        }
-                    }
-                }
-            }
-        )+
-    };
-}
-
-impl_vec_produce!(i64, f64,);
-
 impl<'r, 'a> Produce<'r, bool> for BigQuerySourceParser {
     type Error = BigQuerySourceError;
 
