@@ -1,3 +1,4 @@
+use std::string::FromUtf8Error;
 use thiserror::Error;
 
 #[derive(Error, Debug)]
@@ -20,6 +21,9 @@ pub enum MsSQLSourceError {
     #[error(transparent)]
     MsSQLUrlError(#[from] url::ParseError),
 
+    #[error(transparent)]
+    MsSQLUrlDecodeError(#[from] FromUtf8Error),
+
     /// Any other errors that are too trivial to be put here explicitly.
     #[error(transparent)]
     Other(#[from] anyhow::Error),
